@@ -2,6 +2,7 @@ import sys
 import os
 import urllib.request
 import loadwave
+import time
 
 def main():
     arg = sys.argv[1]
@@ -100,32 +101,37 @@ def main():
             new_folder = os.path.join(os.environ['APPDATA'], "kenucorp", "modules")
             os.makedirs(new_folder, exist_ok=True)
             print("Loading...")
-            filepath = os.path.join(os.environ['APPDATA'], "kenucorp", "modules") + f"\\{modul}"
+            filepath = os.path.join(os.environ['APPDATA'], "kenucorp", "modules") + "\\" + modul + "\\" + modul + ".py"
             kenan = downloadModule(modul, filepath)
             if kenan:
                 print("\nThe module downloaded successfully.")
             else:
                 print("\nNo such module found.")
 @loadwave.process 
-def downloadModule(name, filepath):
+def downloadModule(module, filepath):
     try:
-        if("kenu" in name):
-            urllib.request.urlretrieve("https://kenucorp.com/modules/" + name + ".knu", filepath)
+        if("kenu" in module):
+            urllib.request.urlretrieve("https://kenucorp.com/modules/" + module + ".knu", filepath)
         else:
-            name = os.path.join(os.environ['APPDATA'], "kenucorp", "modules") + f"\\{name}"
+            name = os.path.join(os.environ['APPDATA'], "kenucorp", "modules") + f"\\{module}"
             if not os.path.exists(name):
                 os.makedirs(name)
-            urllib.request.urlretrieve(f"https://kenucorp.com/modules/" + name + ".py", name + "\\{name}\\{name}.py")
-            urllib.request.urlretrieve(f"https://kenucorp.com/modules/{name}requirements.txt", name + "\\{name}\\requirements.txt")
-            try:
-                with open(name + "\\requirements.txt", 'r') as file:
-                    line = file.readline()
-                    while line:
-                        os.systs
-                        line = file.readline()
-            except:
-                pass
+            urllib.request.urlretrieve(f"https://kenucorp.com/modules/" + module + ".py", f"{name}\{module}.py")
+            urllib.request.urlretrieve(f"https://kenucorp.com/modules/{module}requirements.txt", f"{name}\\requirements.txt")
+            with open(name + "\\requirements.txt", 'r') as file:
+                line = file.readline()
+                if(line != ""):
+                    uploadmodules(name)
+        time.sleep(2.7)
         return True
     except Exception as e:
         print(e)
-        return False
\ No newline at end of file
+        return False
+
+@loadwave.process
+def uploadmodules(modulename):
+    with open(modulename + "\\requirements.txt", 'r') as file:
+        line = file.readline()
+        while line:
+            line = file.readline()
+            os.system("pip install " + line)
\ No newline at end of file
